pub mod metar_tab;

use std::fmt::Display;

// Strum Package to make enum Itterable
use strum::EnumIter;
use strum::IntoEnumIterator;

use crate::App;

#[derive(Debug, Default, EnumIter, PartialEq, Eq)]
pub enum Tabs {
    #[default]
    Home,
    METAR(metar_tab::MetarTab),
    TAF,
    NOTAMS,
    Routing,
}

impl Display for Tabs {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::METAR(_) => write!(f, "METAR"),
            _ => write!(f, "{}", format!("{:?}", self)),
        }
    }
}

#[derive(Default)]
pub struct TabState {
    pub current_tab: Tabs,
}

/// Tab traits that allow tab display on the main application window
pub trait Tab {
    fn display_tab(&mut self, ctx: &egui::Context);
}

/// Function to draw main set of tabs on the window
pub fn display_tabs(app: &mut App, ctx: &egui::Context) {
    egui::TopBottomPanel::top("app_top_bar").show(ctx, |ui| {
        ui.horizontal_wrapped(|ui| {
            ui.visuals_mut().button_frame = false;

            // Insert Tabs
            for tab in Tabs::iter() {
                let tab_label =
                    ui.selectable_label(tab == app.tab_state.current_tab, format!("{}", tab));

                if tab_label.clicked() {
                    app.tab_state.current_tab = tab
                }
            }
        });
    });
}
